searchData={"items":[{"type":"module","title":"SAT","doc":"Documentation for `SAT` (Servicio de Administración Tributaria) for Mexico.\n\nOverview\nTransforming a CFDI (Comprobante Fiscal Digital por Internet) invoice from XML format to a `map` struct.\n\nAlso we are capable for generating a report for withholding ISR (Impuesto Sobre la Renta) taxes via `SAT.Report.ISR`.","ref":"SAT.html"},{"type":"module","title":"SAT.Report.ISR","doc":"Get a `summarized` report for withholdings ISR taxes.","ref":"SAT.Report.ISR.html"},{"type":"function","title":"SAT.Report.ISR.custom_round/1","doc":"Round according to SAT: fractional part > 0.50 → up; else (≤ 0.50) → down.","ref":"SAT.Report.ISR.html#custom_round/1"},{"type":"function","title":"SAT.Report.ISR.round_withholdings/1","doc":"Apply SAT rounding to each {tax_id, gross_amount, tax_withheld} tuple,\nreturning {tax_id, rounded_gross, rounded_withheld} with integer values.","ref":"SAT.Report.ISR.html#round_withholdings/1"},{"type":"function","title":"SAT.Report.ISR.round_withholdings_detailed/1","doc":"Apply SAT rounding to each {tax_id, gross_amount, tax_withheld} tuple,\nreturning {tax_id, rounded_gross, rounded_withheld} with integer values.\nThe output is a list of maps with the following keys:\n- `tax_id`: The tax ID of the person who is withholding the tax.\n- `incoming`: The total amount of the invoice.\n- `withheld`: The total amount of the tax withheld.","ref":"SAT.Report.ISR.html#round_withholdings_detailed/1"},{"type":"function","title":"SAT.Report.ISR.withholdings/2","doc":"Expects a directory with the `XML` invoices to build the a grouped list.\nSupports both individual XML files and ZIP files containing XML files.","ref":"SAT.Report.ISR.html#withholdings/2"},{"type":"function","title":"SAT.Report.ISR.withholdings_summarize/1","doc":"Expects the output obtained via `withholdings/1` to return the summarized result.\n\nThis helps to get the right values to do the details for withheld tax by a moral person.","ref":"SAT.Report.ISR.html#withholdings_summarize/1"},{"type":"function","title":"SAT.Report.ISR.withholdings_summarize_detailed/1","doc":"Expects the output obtained via `withholdings/1` to return the summarized result.\nThis helps to get the right values to do the details for withheld tax by a moral person.\n\nThe output is a list of maps with the following keys:\n- `tax_id`: The tax ID of the person who is withholding the tax.\n- `incoming`: The total amount of the invoice.\n- `withheld`: The total amount of the tax withheld.","ref":"SAT.Report.ISR.html#withholdings_summarize_detailed/1"},{"type":"extras","title":"SAT Mexico ISR Report","doc":"# SAT Mexico ISR Report\n\nThis tutorial will guide you through using the SAT.Report.ISR module to generate ISR (Impuesto Sobre la Renta) reports from your SAT XML invoices.","ref":"isr_report.html"},{"type":"extras","title":"Overview - SAT Mexico ISR Report","doc":"The SAT.Report.ISR module helps you process SAT XML invoices to extract and summarize ISR tax withholding information. It supports:\n\n- Processing individual XML files\n- Processing ZIP files containing XML files\n- Searching in nested directories\n- Summarizing withholding data\n- Rounding according to SAT rules","ref":"isr_report.html#overview"},{"type":"extras","title":"Basic Usage - SAT Mexico ISR Report","doc":"","ref":"isr_report.html#basic-usage"},{"type":"extras","title":"1. Generate Withholding Report - SAT Mexico ISR Report","doc":"```elixir\n# Basic usage - process all XML and ZIP files in a directory and its subdirectories\nwithholdings = SAT.Report.ISR.withholdings(\"/path/to/your/invoices\")\n\n# Disable nested directory search (only process files in the top directory)\nwithholdings = SAT.Report.ISR.withholdings(\"/path/to/your/invoices\", false)\n```\n\nThe withholdings/2 function returns a map where:\n\n- Keys are the retainer tax IDs\n- Values are lists of records containing:\n  - retainer_tax_id : The tax ID of the entity that withheld the tax\n  - amount_incoming : The total invoice amount\n  - amount_withheld : The ISR tax amount withheld","ref":"isr_report.html#1-generate-withholding-report"},{"type":"extras","title":"2. Summarize Withholding Data - SAT Mexico ISR Report","doc":"```elixir\n# Get a simple summary as tuples {tax_id, total_incoming, total_withheld}\nsummary = SAT.Report.ISR.withholdings_summarize(withholdings)\n\n# Get a detailed summary as maps with keys :tax_id, :incoming, :withheld\ndetailed_summary = SAT.Report.ISR.withholdings_summarize_detailed(withholdings)\n```","ref":"isr_report.html#2-summarize-withholding-data"},{"type":"extras","title":"3. Apply SAT Rounding Rules - SAT Mexico ISR Report","doc":"```elixir\n# Round according to SAT rules (as tuples)\nrounded = SAT.Report.ISR.round_withholdings(withholdings)\n\n# Round according to SAT rules (as maps)\nrounded_detailed = SAT.Report.ISR.round_withholdings_detailed(withholdings)\n```","ref":"isr_report.html#3-apply-sat-rounding-rules"},{"type":"extras","title":"Complete Example - SAT Mexico ISR Report","doc":"```elixir\n# Process all XML and ZIP files in a directory and its subdirectories\nwithholdings = SAT.Report.ISR.withholdings(\"/Volumes/data/defdo_projects/defdo_my_mvno/priv/sat/xml\")\n\n# Get a detailed summary with SAT rounding applied\nresult = withholdings\n  |> SAT.Report.ISR.withholdings_summarize_detailed()\n  |> SAT.Report.ISR.round_withholdings_detailed()\n\n# Print the results\nEnum.each(result, fn %{tax_id: tax_id, incoming: incoming, withheld: withheld} ->\n  IO.puts(\"Tax ID: #{tax_id}, Total: #{incoming}, Withheld: #{withheld}\")\nend)\n```\n\nor if you don't want detailed summary:\n\n```elixir\nwithholdings = SAT.Report.ISR.withholdings(\"/path/to/your/invoices\" )\n\nresult = \n    withholdings\n    |> SAT.Report.ISR.withholdings() \n    |> SAT.Report.ISR.withholdings_summarize()\n    |> SAT.Report.ISR.round_withholdings() \n\nEnum.each(result, fn {tax_id, incoming, withheld} -> \n    IO.puts(\"#{tax_id}|#{incoming}|#{withheld}\")\nend)\n```","ref":"isr_report.html#complete-example"},{"type":"extras","title":"Advanced Features - SAT Mexico ISR Report","doc":"","ref":"isr_report.html#advanced-features"},{"type":"extras","title":"Custom Rounding - SAT Mexico ISR Report","doc":"The module uses a special rounding rule for SAT:\n\n- If fractional part ≥ 0.60, round up\n- If fractional part < 0.60, round down\nYou can use this rounding function directly:\n\n```elixir\n# Round a decimal value according to SAT rules\nrounded = SAT.Report.ISR.custom_round(Decimal.new(\"123.59\"))  # Returns 123\nrounded = SAT.Report.ISR.custom_round(Decimal.new(\"123.61\"))  # Returns 124\n```","ref":"isr_report.html#custom-rounding"},{"type":"extras","title":"File Support - SAT Mexico ISR Report","doc":"The module supports:\n\n- Individual XML files\n- ZIP files containing XML files\n- Nested directory structures\nWhen processing ZIP files, the module:\n\n1. Extracts the ZIP files to a temporary directory\n2. Processes all XML files found inside\n3. Automatically cleans up the temporary files","ref":"isr_report.html#file-support"},{"type":"extras","title":"Notes - SAT Mexico ISR Report","doc":"- The module specifically looks for ISR tax withholdings (tax ID \"001\")\n- Make sure your XML files are valid CFDI documents\n- For large datasets, consider the memory implications of processing many files at once\nThis tutorial should help you remember how to use the `SAT.Report.ISR` module for generating ISR reports from your SAT XML invoices.","ref":"isr_report.html#notes"},{"type":"extras","title":"SAT Mexico","doc":"# SAT Mexico\n\nA comprehensive Elixir library for interacting with Mexican tax authority (SAT - Servicio de Administración Tributaria) invoices and generating tax reports.","ref":"readme.html"},{"type":"extras","title":"Features - SAT Mexico","doc":"- CFDI XML Parsing: Transform CFDI (Comprobante Fiscal Digital por Internet) invoices from XML format to structured Elixir maps\n- ISR Tax Reporting: Generate withholding tax (ISR - Impuesto Sobre la Renta) reports from invoice data\n- Batch Processing: Process multiple invoices from directories, including nested XML files and ZIPs\n- SAT Compliant: Implements official SAT rounding rules and tax calculations\n- Reference Data: Includes up-to-date catalogs for tax regimes and CFDI usage codes","ref":"readme.html#features"},{"type":"extras","title":"Installation - SAT Mexico","doc":"Add sat_mexico to your list of dependencies in mix.exs:\n\n```elixir\ndef deps do\n  [\n    {:sat_mexico, \"~> 0.2.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - SAT Mexico","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Parsing CFDI Invoices - SAT Mexico","doc":"```elixir\n# Parse a single XML invoice\n{:ok, document} = File.read(\"path/to/invoice.xml\")\n{:ok, invoice} = Saxy.parse_string(document, SAT.InvoiceHandler, [])\n\n# Access invoice data\ninvoice.total          # => \"2944.00\"\ninvoice.currency       # => \"MXN\"\ninvoice.issuer.tax_id  # => \"SAT970701NN3\"\n```\n\nGenerating ISR Reports\n\n```elixir\n# Process all XML and ZIP files in a directory and its subdirectories\nwithholdings = SAT.Report.ISR.withholdings(\"/path/to/invoices\")\n\n# Get a detailed summary with SAT rounding applied\nresult = withholdings\n  |> SAT.Report.ISR.withholdings_summarize_detailed()\n  |> SAT.Report.ISR.round_withholdings_detailed()\n\n# Print the results\nEnum.each(result, fn %{tax_id: tax_id, incoming: incoming, withheld: withheld} ->\n  IO.puts(\"Tax ID: #{tax_id}, Total: #{incoming}, Withheld: #{withheld}\")\nend)\n```\n\nFor more detailed examples, see the [ISR Report Guide](/lib/sat/guides/isr_report.md).","ref":"readme.html#parsing-cfdi-invoices"},{"type":"extras","title":"Reference Data - SAT Mexico","doc":"The library includes comprehensive reference data for:\n\n- Tax Regimes: Complete catalog of Mexican tax regimes with validity dates and applicability\n- CFDI Usage Codes: Full catalog of CFDI usage codes with descriptions and validity information","ref":"readme.html#reference-data"},{"type":"extras","title":"Documentation - SAT Mexico","doc":"Full documentation is available at  .","ref":"readme.html#documentation"},{"type":"extras","title":"Contributing - SAT Mexico","doc":"Contributions are welcome! Please feel free to submit a Pull Request.\n\n1. Fork the repository\n2. Create your feature branch (git checkout -b feature/amazing-feature)\n3. Commit your changes (git commit -m 'Add some amazing feature')\n4. Push to the branch (git push origin feature/amazing-feature)\n5. Open a Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"License - SAT Mexico","doc":"This project is licensed under the Apache License 2.0 - see the [LICENSE.md](./LICENSE.md) file for details.","ref":"readme.html#license"},{"type":"extras","title":"About - SAT Mexico","doc":"SAT Mexico is maintained by [defdo](https://defdo.dev).","ref":"readme.html#about"},{"type":"extras","title":"LICENSE","doc":"Apache License\n                           Version 2.0, January 2004\n                        http://www.apache.org/licenses/\n\nTERMS AND CONDITIONS FOR USE, REPRODUCTION, AND DISTRIBUTION\n\n1.  Definitions.\n\n    \"License\" shall mean the terms and conditions for use, reproduction,\n    and distribution as defined by Sections 1 through 9 of this document.\n\n    \"Licensor\" shall mean the copyright owner or entity authorized by\n    the copyright owner that is granting the License.\n\n    \"Legal Entity\" shall mean the union of the acting entity and all\n    other entities that control, are controlled by, or are under common\n    control with that entity. For the purposes of this definition,\n    \"control\" means (i) the power, direct or indirect, to cause the\n    direction or management of such entity, whether by contract or\n    otherwise, or (ii) ownership of fifty percent (50%) or more of the\n    outstanding shares, or (iii) beneficial ownership of such entity.\n\n    \"You\" (or \"Your\") shall mean an individual or Legal Entity\n    exercising permissions granted by this License.\n\n    \"Source\" form shall mean the preferred form for making modifications,\n    including but not limited to software source code, documentation\n    source, and configuration files.\n\n    \"Object\" form shall mean any form resulting from mechanical\n    transformation or translation of a Source form, including but\n    not limited to compiled object code, generated documentation,\n    and conversions to other media types.\n\n    \"Work\" shall mean the work of authorship, whether in Source or\n    Object form, made available under the License, as indicated by a\n    copyright notice that is included in or attached to the work\n    (an example is provided in the Appendix below).\n\n    \"Derivative Works\" shall mean any work, whether in Source or Object\n    form, that is based on (or derived from) the Work and for which the\n    editorial revisions, annotations, elaborations, or other modifications\n    represent, as a whole, an original work of authorship. For the purposes\n    of this License, Derivative Works shall not include works that remain\n    separable from, or merely link (or bind by name) to the interfaces of,\n    the Work and Derivative Works thereof.\n\n    \"Contribution\" shall mean any work of authorship, including\n    the original version of the Work and any modifications or additions\n    to that Work or Derivative Works thereof, that is intentionally\n    submitted to Licensor for inclusion in the Work by the copyright owner\n    or by an individual or Legal Entity authorized to submit on behalf of\n    the copyright owner. For the purposes of this definition, \"submitted\"\n    means any form of electronic, verbal, or written communication sent\n    to the Licensor or its representatives, including but not limited to\n    communication on electronic mailing lists, source code control systems,\n    and issue tracking systems that are managed by, or on behalf of, the\n    Licensor for the purpose of discussing and improving the Work, but\n    excluding communication that is conspicuously marked or otherwise\n    designated in writing by the copyright owner as \"Not a Contribution.\"\n\n    \"Contributor\" shall mean Licensor and any individual or Legal Entity\n    on behalf of whom a Contribution has been received by Licensor and\n    subsequently incorporated within the Work.\n\n2.  Grant of Copyright License. Subject to the terms and conditions of\n    this License, each Contributor hereby grants to You a perpetual,\n    worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n    copyright license to reproduce, prepare Derivative Works of,\n    publicly display, publicly perform, sublicense, and distribute the\n    Work and such Derivative Works in Source or Object form.\n\n3.  Grant of Patent License. Subject to the terms and conditions of\n    this License, each Contributor hereby grants to You a perpetual,\n    worldwide, non-exclusive, no-charge, royalty-free, irrevocable\n    (except as stated in this section) patent license to make, have made,\n    use, offer to sell, sell, import, and otherwise transfer the Work,\n    where such license applies only to those patent claims licensable\n    by such Contributor that are necessarily infringed by their\n    Contribution(s) alone or by combination of their Contribution(s)\n    with the Work to which such Contribution(s) was submitted. If You\n    institute patent litigation against any entity (including a\n    cross-claim or counterclaim in a lawsuit) alleging that the Work\n    or a Contribution incorporated within the Work constitutes direct\n    or contributory patent infringement, then any patent licenses\n    granted to You under this License for that Work shall terminate\n    as of the date such litigation is filed.\n\n4.  Redistribution. You may reproduce and distribute copies of the\n    Work or Derivative Works thereof in any medium, with or without\n    modifications, and in Source or Object form, provided that You\n    meet the following conditions:\n\n    (a) You must give any other recipients of the Work or\n    Derivative Works a copy of this License; and\n\n    (b) You must cause any modified files to carry prominent notices\n    stating that You changed the files; and\n\n    (c) You must retain, in the Source form of any Derivative Works\n    that You distribute, all copyright, patent, trademark, and\n    attribution notices from the Source form of the Work,\n    excluding those notices that do not pertain to any part of\n    the Derivative Works; and\n\n    (d) If the Work includes a \"NOTICE\" text file as part of its\n    distribution, then any Derivative Works that You distribute must\n    include a readable copy of the attribution notices contained\n    within such NOTICE file, excluding those notices that do not\n    pertain to any part of the Derivative Works, in at least one\n    of the following places: within a NOTICE text file distributed\n    as part of the Derivative Works; within the Source form or\n    documentation, if provided along with the Derivative Works; or,\n    within a display generated by the Derivative Works, if and\n    wherever such third-party notices normally appear. The contents\n    of the NOTICE file are for informational purposes only and\n    do not modify the License. You may add Your own attribution\n    notices within Derivative Works that You distribute, alongside\n    or as an addendum to the NOTICE text from the Work, provided\n    that such additional attribution notices cannot be construed\n    as modifying the License.\n\n    You may add Your own copyright statement to Your modifications and\n    may provide additional or different license terms and conditions\n    for use, reproduction, or distribution of Your modifications, or\n    for any such Derivative Works as a whole, provided Your use,\n    reproduction, and distribution of the Work otherwise complies with\n    the conditions stated in this License.\n\n5.  Submission of Contributions. Unless You explicitly state otherwise,\n    any Contribution intentionally submitted for inclusion in the Work\n    by You to the Licensor shall be under the terms and conditions of\n    this License, without any additional terms or conditions.\n    Notwithstanding the above, nothing herein shall supersede or modify\n    the terms of any separate license agreement you may have executed\n    with Licensor regarding such Contributions.\n\n6.  Trademarks. This License does not grant permission to use the trade\n    names, trademarks, service marks, or product names of the Licensor,\n    except as required for reasonable and customary use in describing the\n    origin of the Work and reproducing the content of the NOTICE file.\n\n7.  Disclaimer of Warranty. Unless required by applicable law or\n    agreed to in writing, Licensor provides the Work (and each\n    Contributor provides its Contributions) on an \"AS IS\" BASIS,\n    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\n    implied, including, without limitation, any warranties or conditions\n    of TITLE, NON-INFRINGEMENT, MERCHANTABILITY, or FITNESS FOR A\n    PARTICULAR PURPOSE. You are solely responsible for determining the\n    appropriateness of using or redistributing the Work and assume any\n    risks associated with Your exercise of permissions under this License.\n\n8.  Limitation of Liability. In no event and under no legal theory,\n    whether in tort (including negligence), contract, or otherwise,\n    unless required by applicable law (such as deliberate and grossly\n    negligent acts) or agreed to in writing, shall any Contributor be\n    liable to You for damages, including any direct, indirect, special,\n    incidental, or consequential damages of any character arising as a\n    result of this License or out of the use or inability to use the\n    Work (including but not limited to damages for loss of goodwill,\n    work stoppage, computer failure or malfunction, or any and all\n    other commercial damages or losses), even if such Contributor\n    has been advised of the possibility of such damages.\n\n9.  Accepting Warranty or Additional Liability. While redistributing\n    the Work or Derivative Works thereof, You may choose to offer,\n    and charge a fee for, acceptance of support, warranty, indemnity,\n    or other liability obligations and/or rights consistent with this\n    License. However, in accepting such obligations, You may act only\n    on Your own behalf and on Your sole responsibility, not on behalf\n    of any other Contributor, and only if You agree to indemnify,\n    defend, and hold each Contributor harmless for any liability\n    incurred by, or claims asserted against, such Contributor by reason\n    of your accepting any such warranty or additional liability.\n\nEND OF TERMS AND CONDITIONS\n\nAPPENDIX: How to apply the Apache License to your work.\n\n      To apply the Apache License to your work, attach the following\n      boilerplate notice, with the fields enclosed by brackets \"[]\"\n      replaced with your own identifying information. (Don't include\n      the brackets!)  The text should be enclosed in the appropriate\n      comment syntax for the file format. We also recommend that a\n      file or class name and description of purpose be included on the\n      same \"printed page\" as the copyright notice for easier\n      identification within third-party archives.\n\nCopyright [2024] [defdo]\n\nLicensed under the Apache License, Version 2.0 (the \"License\");\nyou may not use this file except in compliance with the License.\nYou may obtain a copy of the License at\n\n       http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software\ndistributed under the License is distributed on an \"AS IS\" BASIS,\nWITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\nSee the License for the specific language governing permissions and\nlimitations under the License.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.2.0 (2025-04-27) - Changelog","doc":"- Support for processing ZIP files containing XML invoices.\n- Support for nested directory searching when processing invoice files.\n- Detailed summarization of withholding data with `withholdings_summarize` and `withholdings_summarize_detailed`.\n- SAT-compliant rounding functionality for tax calculations.\n- Automatic cleanup of temporary files after processing.","ref":"changelog.html#0-2-0-2025-04-27"},{"type":"extras","title":"0.1.0 (2024-04-29) - Changelog","doc":"- CFDI invoice transformation from `XML` to `map` struct via `SAT.Handler`.\n- CFDI report for withholdings ISR taxes.","ref":"changelog.html#0-1-0-2024-04-29"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}